import React, { useCallback, useContext } from 'react';
import styles from '../styles/styles.module.css';
import { productContext } from './ProductCard';

export interface Props {
    className?: string;
    style?: React.CSSProperties
}

export const ProductButtons = ({ className, style }: Props) => {

    const { increaseBy, counter, maxCount } = useContext(productContext);

    const isMaxReachd = useCallback(
        () => !!maxCount && counter === maxCount,
        [counter, maxCount],
    );


    return (
        <div
            className={`${styles.buttonsContainer} ${className}`}
            style={style}
        >
            <button
                className={styles.buttonMinus}
                onClick={() => increaseBy(-1)}>-</button>

            <div className={styles.countLabel}>{counter}</div>

            <button
                className={`${styles.buttonAdd} ${isMaxReachd() && styles.disabled}`}
                onClick={() => increaseBy(+1)}>+</button>
        </div>
    );
}